package cn.com.infosec.asn1.x500;

import cn.com.infosec.asn1.ASN1Choice;
import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERBMPString;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERPrintableString;
import cn.com.infosec.asn1.DERString;
import cn.com.infosec.asn1.DERT61String;
import cn.com.infosec.asn1.DERUTF8String;
import cn.com.infosec.asn1.DERUniversalString;

public class DirectoryString extends ASN1Encodable implements ASN1Choice, DERString {
   private DERString string;

   public static DirectoryString getInstance(Object o) {
      if (o instanceof DirectoryString) {
         return (DirectoryString)o;
      } else if (o instanceof DERT61String) {
         return new DirectoryString((DERT61String)o);
      } else if (o instanceof DERPrintableString) {
         return new DirectoryString((DERPrintableString)o);
      } else if (o instanceof DERUniversalString) {
         return new DirectoryString((DERUniversalString)o);
      } else if (o instanceof DERUTF8String) {
         return new DirectoryString((DERUTF8String)o);
      } else if (o instanceof DERBMPString) {
         return new DirectoryString((DERBMPString)o);
      } else {
         throw new IllegalArgumentException("illegal object in getInstance: " + o.getClass().getName());
      }
   }

   public static DirectoryString getInstance(ASN1TaggedObject o, boolean explicit) {
      if (explicit) {
         return getInstance(o.getObject());
      } else {
         throw new IllegalArgumentException("choice item must be explicitly tagged");
      }
   }

   private DirectoryString(DERT61String string) {
      this.string = string;
   }

   private DirectoryString(DERPrintableString string) {
      this.string = string;
   }

   private DirectoryString(DERUniversalString string) {
      this.string = string;
   }

   private DirectoryString(DERUTF8String string) {
      this.string = string;
   }

   private DirectoryString(DERBMPString string) {
      this.string = string;
   }

   public DirectoryString(String string) {
      DirectoryString var10000 = this;
      super();
      DERUTF8String var2;
      var2 = new DERUTF8String.<init>(string);
      var10000.string = var2;
   }

   public String getString() {
      return this.string.getString();
   }

   public String toString() {
      return this.string.getString();
   }

   public DERObject toASN1Object() {
      return ((DEREncodable)this.string).getDERObject();
   }
}
